==> spip_4.2.13+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_eu.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=eu
// ** ne pas modifier le fichier **

return [

	// A
	'aucun_message_forum' => 'Iruzkinik ez',

	// B
	'bouton_radio_articles_futurs' => 'geroko artikuluei soilik (ez du aldatzen datu-basea).',
	'bouton_radio_articles_tous' => 'artikulu guztiei, salbuespenik gabe.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'artikulu guztiei, desaktibatutako foroan daudenei izan ezik.',
	'bouton_radio_enregistrement_obligatoire' => 'Izena ematea derrigorrezkoa da (foroan parte hartu ahal izateko, inskripzioa egin behar da posta elektronikoaren helbidea emanez).',
	'bouton_radio_moderation_priori' => 'Aurretiaz moderatua (ekarpenak agerian egongodira lekuaren administrazio-eskubideak dituen pertsona batek onartu eta gero).',
	'bouton_radio_modere_abonnement' => 'Moderatua (harpidedunentzat soilik)',
	'bouton_radio_modere_posteriori' => 'gerora moderatua',
	'bouton_radio_modere_priori' => 'aurretiaz moderatua',
	'bouton_radio_publication_immediate' => 'Iruzkinen bat-bateko argitaratzea (erakarpenak agerian egongo dira igorri bezain laister, gero administraziotik kendu daitezke).',

	// D
	'documents_interdits_forum' => 'Dokumentuak debekatuak dira foroetan',

	// E
	'erreur_enregistrement_message' => 'Zure iruzkinaren garbaketak huts egin du, akats tekniko batengatik',
	'extensions_autorisees' => 'Baimendutako fitxategien atzizkia:',
	'extensions_autorisees_toutes' => 'guztiak',

	// F
	'form_pet_message_commentaire' => 'Mezurik, iruzkinik ?',
	'forum' => 'Foroa',
	'forum_acces_refuse' => 'Dagoeneko ezin zara foro hauetan sartu.',
	'forum_attention_dix_caracteres' => '<b>Adi!</b> zure iruzkinak hamar karaktere baino gutxiago ditu',
	'forum_attention_message_non_poste' => 'Kontuz, mezua ez duzu igorria !',
	'forum_attention_nb_caracteres_mini' => '<b>Adi!</b> zure mezuak @min@ karaketre bederen eduki behar ditu.',
	'forum_attention_trois_caracteres' => '<b>Adi!</b> zure izenburuak hiru karaktere baino gutxiago ditu.',
	'forum_attention_trop_caracteres' => '<b>Adi!</b> zure mezua luzeegi da (@compte@ caractères) : grabatua izateko, ez ditu @max@ karaktero baino gehiago izan behar.',
	'forum_avez_selectionne' => 'Aukeratu egin duzu:',
	'forum_cliquer_retour' => 'Jarraitzeko hemen klik egin.',
	'forum_envoyer' => 'Bidali',
	'forum_forum' => 'foroa',
	'forum_info_modere' => 'Foro hau aurretiaz moderaturik dago : 
Zure ekarpena gunearen administratzaileak onartu ondoren soilik agerian izango da.',
	'forum_lien_hyper' => 'Hiperesteka (aukeratzekoa)',
	'forum_message' => 'Zure mezua',
	'forum_message_definitif' => 'Behin-betiko mezua : gunera igorri',
	'forum_message_trop_long' => 'Zure mezua luzeegia da. 20 000 karaktere gehienez onartzen dira.',
	'forum_ne_repondez_pas' => 'Ez erantzun mezu elektroniko honi, baizik eta hurrengo helbidean dagoen foroan:',
	'forum_page_url' => '(Zure mezua interneten argitaratutako artikulu bati buruzkoa baldin bada, edo informazio gehiago duen orrialde bati buruzkoa, adieraz itzazu jarraian orrialdearen izena bai eta URL helbidea ere).',
	'forum_permalink' => 'Iruzkinari lotura iraunkorra',
	'forum_poste_par' => '« @titre@ » artikuluaren ondotik  @parauteur@-k bidalitako mezua.',
	'forum_poste_par_court' => 'Mezu igorlea @parauteur@.',
	'forum_poste_par_generique' => 'Iruzkina igorria @parauteur@ (@objet@ « @titre@ »).',
	'forum_qui_etes_vous' => '<b>Nor zara ?</b> (aukerazkoa)',
	'forum_saisie_texte_info' => 'Inprimaki honek Spip lasterbideak onartzen ditu <code>[-&gt;url] {{gizena}} {etzana} &lt;quote&gt; &lt;code&gt; </code> eta HTML kodeak <code>&lt;q&gt; &lt;del&gt; &lt;ins&gt;</code>. Paragrafoak sortzeko, lerro bat hutsik utz.',
	'forum_texte' => 'Zure iruzkinaren testua:',
	'forum_titre' => 'Izenburua',
	'forum_url' => 'Zure webgunea',
	'forum_valider' => 'Aukera hori onartu',
	'forum_voir_avant' => 'Aurreikusi',
	'forum_votre_email' => 'Zure helbide elektronikoa',
	'forum_votre_nom' => 'Zure izena (edo goitizena) :',
	'forum_vous_enregistrer' => 'Aurretik inskribatzea beharrezkoa da foro honetan parte hartzeko.
Hornitua izan zaizun identifikadore pertsonala jarraian adieraztea eskertuko dizugu.
Inskribaturik ez bazaude, aurretik inskribatu behar duzu.',
	'forum_vous_inscrire' => 'Aurretik inskriba zaitez.',

	// I
	'icone_bruler_message' => 'Spam gisa salatu',
	'icone_bruler_messages' => 'Spam gisa salatu',
	'icone_legitimer_message' => 'Onargarri gisa seinalatu',
	'icone_poster_message' => 'Mezu bat igorri',
	'icone_suivi_forum' => 'Foro publikoaren gaurkotasuna: @nb_forums@ekarpena(k)',
	'icone_suivi_forums' => 'Foroen gestioa',
	'icone_supprimer_message' => 'Mezu hau kendu',
	'icone_supprimer_messages' => 'Mezu hauek ezabatu',
	'icone_valider_message' => 'Mezu hau onartu',
	'icone_valider_messages' => 'Mezu hauek onartu',
	'icone_valider_repondre_message' => 'Mezu hau onartu eta erantzun',
	'info_1_message_forum' => 'Iruzkin bat',
	'info_activer_forum_public' => 'Foru publikoak aktibatzeko, aukeratu lehenetsitako moderazio erabat',
	'info_appliquer_choix_moderation' => 'Moderazio mota hau ezarri',
	'info_config_forums_prive' => 'Eremu pribatuan foro mota desberdinak aktibatzen ahal dituzu',
	'info_config_forums_prive_admin' => 'gunearen administratzaileei erreserbatutako foroa :',
	'info_config_forums_prive_global' => 'Foro orokor bat, idazle guziei irekia :',
	'info_config_forums_prive_objets' => 'Foro bat artikulu, berri-labur edo erreferentzitutako gune bakoitzaren azpian :',
	'info_desactiver_forum_public' => 'Foro publikoak desaktibatu. Puntualki aktiba daiteke artikuluendako artikuluetarako, baina ez berri-laburretarako edo ataletarako.',
	'info_envoi_forum' => 'Foroen jarraipena',
	'info_fonctionnement_forum' => 'Foroarenfuntzionamendua',
	'info_forcer_previsualisation_court' => 'Aurreikuspena behartu',
	'info_forcer_previsualisation_long' => 'Aurreikuspena behartu iruzkina bidali baino lehen',
	'info_forums_liees_mot' => 'Hitz honi lotutako iruzkinak',
	'info_gauche_suivi_forum_2' => 'Foroak jarraitzeko orrialdea zureguneko kudeaketa-tresna bat da (eta ez eztabaida edo idazketa-eremu bat). Guneko foroetako kontribuzio guztiak bistaratzen ditu, bai gune publikokoak bai eremu pribatukoak eta kontribuzio hauek administratzen uzten dizu.',
	'info_liens_syndiques_3' => 'foroak',
	'info_liens_syndiques_4' => 'daude',
	'info_liens_syndiques_5' => 'foroa',
	'info_liens_syndiques_6' => 'dago',
	'info_liens_syndiques_7' => 'balidazioaren zain',
	'info_liens_texte' => 'Iruzkinak edukitako hiperesteka(k)',
	'info_liens_titre' => 'Iruzkinaren izenburuak edukitako hiperesteka(k)',
	'info_mode_fonctionnement_defaut_forum_public' => 'Foro publikoenfuntzionamendua',
	'info_nb_messages_forum' => '@nb@ iruzkin',
	'info_option_email' => 'Guneko bisitari batek artikulu batekin erlazionatutako mezu berri bat bidaltzen duenean foroan, artikuluaren idazleak mezu honetaz abisatuakizan ahal dira e-mailez. Aukera hau erabili nahi duzu ?',
	'info_pas_de_forum' => 'fororik ez',
	'info_question_visiteur_ajout_document_forum' => 'Foroko mezuei dokumentuen eranstea onartzen baduzu (irudi, soinu..), onartutako fitxategi-luzapenak zehaztu itzazu ((ad : gif, jpg, p,png,mp3).',
	'info_question_visiteur_ajout_document_forum_format' => 'Beharrez, zehaztu izkizu foroetako dokumentu erantsien fitxategi-luzapen onartuak (ad : gif, jpg, png, mp3).',
	'info_selectionner_message' => 'Mezuak hautatu :',
	'interface_formulaire' => 'Inprimaki interfazea',
	'interface_onglets' => 'Fitxekilako interfazea',
	'item_activer_forum_administrateur' => 'Administrazio-taldearen foroa aktibatu.',
	'item_config_forums_prive_global' => 'Idazleen foroa aktibatu',
	'item_config_forums_prive_objets' => 'Foro hauek aktibatu',
	'item_desactiver_forum_administrateur' => 'Administrazio-foroa desaktibatu',
	'item_non_config_forums_prive_global' => 'idazleen foroa desaktibatu',
	'item_non_config_forums_prive_objets' => 'Foro hauek desaktibatu',

	// L
	'label_selectionner' => 'Hautatu :',
	'lien_reponse_article' => 'Artikuluari erantzuna',
	'lien_reponse_breve_2' => 'Atalari erantzuna',
	'lien_reponse_message' => 'Mezuari erantzuna',
	'lien_reponse_rubrique' => 'Atalari erantzuna',
	'lien_reponse_site_reference' => 'Aipatutako guneari erantzuna',
	'lien_vider_selection' => 'Selekzioa hustu',

	// M
	'messages_aucun' => 'Bat ere ez',
	'messages_meme_auteur' => 'Autore honen mezu guztiak',
	'messages_meme_email' => 'Helbide elektroniko honen mezu guztia',
	'messages_meme_ip' => 'IP helbide honen mezu guztiak',
	'messages_off' => 'Kenduak',
	'messages_perso' => 'Pertsonala',
	'messages_privadm' => 'Administrazaile',
	'messages_prive' => 'Pribatuak',
	'messages_privoff' => 'Ezabatuak',
	'messages_privrac' => 'Orokorrak',
	'messages_prop' => 'Proposatuak',
	'messages_publie' => 'Argitaratuak',
	'messages_spam' => 'Spam',
	'messages_tous' => 'Guztiak',

	// O
	'onglet_messages_internes' => 'Barne mezuak',
	'onglet_messages_publics' => 'Mezu publikoak',
	'onglet_messages_vide' => 'Testurik gabeko mezuak',

	// R
	'repondre_message' => 'Mezuari erantzun',

	// S
	'statut_off' => 'Ezabatua',
	'statut_original' => 'jatorrizkoa',
	'statut_prop' => 'Proposatuak',
	'statut_publie' => 'Argitaratua',
	'statut_spam' => 'Spam',

	// T
	'text_article_propose_publication_forum' => 'Ez beldurtu zure iritzia emateaz. Artikuluari foro bat lotua zaio (orri beherean).',
	'texte_en_cours_validation' => 'Artikulu, berri-labur eta iruzkin horiek argitalpenarako proposatuak dira.',
	'texte_en_cours_validation_forum' => 'Ez izan zalantzarik zure iritzia emateko beraiei erantsitako foroei esker.',
	'texte_messages_publics' => 'Mezu publikoak hemen :',
	'titre_cadre_forum_administrateur' => 'Administrarien foroa',
	'titre_cadre_forum_interne' => 'Barneko foroa',
	'titre_config_forums_prive' => 'Eremu pribatuko foroak',
	'titre_forum' => 'Barne-foroa',
	'titre_forum_suivi' => 'Foruen kudeaketa',
	'titre_page_forum_suivi' => 'Foruenjarraipena',
	'titre_selection_action' => 'Hautua',
	'tout_voir' => 'Mezu guztiak ikusi',

	// V
	'voir_messages_objet' => 'mezuak ikusi',
];

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_eu.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=eu
// ** ne pas modifier le fichier **

return [

	// A
	'aucun_message_forum' => 'Iruzkinik ez',

	// B
	'bouton_radio_articles_futurs' => 'geroko artikuluei soilik (ez du aldatzen datu-basea).',
	'bouton_radio_articles_tous' => 'artikulu guztiei, salbuespenik gabe.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'artikulu guztiei, desaktibatutako foroan daudenei izan ezik.',
	'bouton_radio_enregistrement_obligatoire' => 'Izena ematea derrigorrezkoa da (foroan parte hartu ahal izateko, inskripzioa egin behar da posta elektronikoaren helbidea emanez).', # MODIF
	'bouton_radio_moderation_priori' => 'Aurretiaz moderatua (ekarpenak agerian egongodira lekuaren administrazio-eskubideak dituen pertsona batek onartu eta gero).', # MODIF
	'bouton_radio_modere_abonnement' => 'Moderatua (harpidedunentzat soilik)',
	'bouton_radio_modere_posteriori' => 'gerora moderatua',
	'bouton_radio_modere_priori' => 'aurretiaz moderatua',
	'bouton_radio_publication_immediate' => 'Iruzkinen bat-bateko argitaratzea (erakarpenak agerian egongo dira igorri bezain laister, gero administraziotik kendu daitezke).', # MODIF

	// D
	'documents_interdits_forum' => 'Dokumentuak debekatuak dira foroetan',

	// E
	'erreur_enregistrement_message' => 'Zure iruzkinaren garbaketak huts egin du, akats tekniko batengatik',
	'extensions_autorisees' => 'Baimendutako fitxategien atzizkia:',
	'extensions_autorisees_toutes' => 'guztiak',

	// F
	'form_pet_message_commentaire' => 'Mezurik, iruzkinik ?',
	'forum' => 'Foroa',
	'forum_acces_refuse' => 'Dagoeneko ezin zara foro hauetan sartu.',
	'forum_attention_dix_caracteres' => '<b>Adi!</b> zure iruzkinak hamar karaktere baino gutxiago ditu',
	'forum_attention_message_non_poste' => 'Kontuz, mezua ez duzu igorria !',
	'forum_attention_nb_caracteres_mini' => '<b>Adi!</b> zure mezuak @min@ karaketre bederen eduki behar ditu.',
	'forum_attention_trois_caracteres' => '<b>Adi!</b> zure izenburuak hiru karaktere baino gutxiago ditu.',
	'forum_attention_trop_caracteres' => '<b>Adi!</b> zure mezua luzeegi da (@compte@ caractères) : grabatua izateko, ez ditu @max@ karaktero baino gehiago izan behar.',
	'forum_avez_selectionne' => 'Aukeratu egin duzu:',
	'forum_cliquer_retour' => 'Jarraitzeko hemen klik egin.',
	'forum_envoyer' => 'Bidali',
	'forum_forum' => 'foroa',
	'forum_info_modere' => 'Foro hau aurretiaz moderaturik dago : 
Zure ekarpena gunearen administratzaileak onartu ondoren soilik agerian izango da.', # MODIF
	'forum_lien_hyper' => 'Hiperesteka (aukeratzekoa)',
	'forum_message' => 'Zure mezua',
	'forum_message_definitif' => 'Behin-betiko mezua : gunera igorri',
	'forum_message_trop_long' => 'Zure mezua luzeegia da. 20 000 karaktere gehienez onartzen dira.',
	'forum_ne_repondez_pas' => 'Ez erantzun mezu elektroniko honi, baizik eta hurrengo helbidean dagoen foroan:',
	'forum_page_url' => '(Zure mezua interneten argitaratutako artikulu bati buruzkoa baldin bada, edo informazio gehiago duen orrialde bati buruzkoa, adieraz itzazu jarraian orrialdearen izena bai eta URL helbidea ere).',
	'forum_permalink' => 'Iruzkinari lotura iraunkorra',
	'forum_poste_par' => '« @titre@ » artikuluaren ondotik  @parauteur@-k bidalitako mezua.',
	'forum_poste_par_court' => 'Mezu igorlea @parauteur@.',
	'forum_poste_par_generique' => 'Iruzkina igorria @parauteur@ (@objet@ « @titre@ »).',
	'forum_qui_etes_vous' => '<b>Nor zara ?</b> (aukerazkoa)',
	'forum_saisie_texte_info' => 'Inprimaki honek Spip lasterbideak onartzen ditu <code>[-&gt;url] {{gizena}} {etzana} &lt;quote&gt; &lt;code&gt; </code> eta HTML kodeak <code>&lt;q&gt; &lt;del&gt; &lt;ins&gt;</code>. Paragrafoak sortzeko, lerro bat hutsik utz.',
	'forum_texte' => 'Zure iruzkinaren testua:',
	'forum_titre' => 'Izenburua',
	'forum_url' => 'Zure webgunea',
	'forum_valider' => 'Aukera hori onartu',
	'forum_voir_avant' => 'Aurreikusi',
	'forum_votre_email' => 'Zure helbide elektronikoa',
	'forum_votre_nom' => 'Zure izena (edo goitizena) :',
	'forum_vous_enregistrer' => 'Aurretik inskribatzea beharrezkoa da foro honetan parte hartzeko.
Hornitua izan zaizun identifikadore pertsonala jarraian adieraztea eskertuko dizugu.
Inskribaturik ez bazaude, aurretik inskribatu behar duzu.',
	'forum_vous_inscrire' => 'Aurretik inskriba zaitez.',

	// I
	'icone_bruler_message' => 'Spam gisa salatu',
	'icone_bruler_messages' => 'Spam gisa salatu',
	'icone_legitimer_message' => 'Onargarri gisa seinalatu',
	'icone_poster_message' => 'Mezu bat igorri',
	'icone_suivi_forum' => 'Foro publikoaren gaurkotasuna: @nb_forums@ekarpena(k)',
	'icone_suivi_forums' => 'Foroen gestioa',
	'icone_supprimer_message' => 'Mezu hau kendu',
	'icone_supprimer_messages' => 'Mezu hauek ezabatu',
	'icone_valider_message' => 'Mezu hau onartu',
	'icone_valider_messages' => 'Mezu hauek onartu',
	'icone_valider_repondre_message' => 'Mezu hau onartu eta erantzun',
	'info_1_message_forum' => 'Iruzkin bat',
	'info_activer_forum_public' => 'Foru publikoak aktibatzeko, aukeratu lehenetsitako moderazio erabat',
	'info_appliquer_choix_moderation' => 'Moderazio mota hau ezarri',
	'info_config_forums_prive' => 'Eremu pribatuan foro mota desberdinak aktibatzen ahal dituzu',
	'info_config_forums_prive_admin' => 'gunearen administratzaileei erreserbatutako foroa :', # MODIF
	'info_config_forums_prive_global' => 'Foro orokor bat, idazle guziei irekia :', # MODIF
	'info_config_forums_prive_objets' => 'Foro bat artikulu, berri-labur edo erreferentzitutako gune bakoitzaren azpian :',
	'info_desactiver_forum_public' => 'Foro publikoak desaktibatu. Puntualki aktiba daiteke artikuluendako artikuluetarako, baina ez berri-laburretarako edo ataletarako.',
	'info_envoi_forum' => 'Foroen jarraipena', # MODIF
	'info_fonctionnement_forum' => 'Foroarenfuntzionamendua',
	'info_forcer_previsualisation_court' => 'Aurreikuspena behartu',
	'info_forcer_previsualisation_long' => 'Aurreikuspena behartu iruzkina bidali baino lehen',
	'info_forums_liees_mot' => 'Hitz honi lotutako iruzkinak',
	'info_gauche_suivi_forum_2' => 'Foroak jarraitzeko orrialdea zureguneko kudeaketa-tresna bat da (eta ez eztabaida edo idazketa-eremu bat). Guneko foroetako kontribuzio guztiak bistaratzen ditu, bai gune publikokoak bai eremu pribatukoak eta kontribuzio hauek administratzen uzten dizu.',
	'info_liens_syndiques_3' => 'foroak',
	'info_liens_syndiques_4' => 'daude',
	'info_liens_syndiques_5' => 'foroa',
	'info_liens_syndiques_6' => 'dago',
	'info_liens_syndiques_7' => 'balidazioaren zain',
	'info_liens_texte' => 'Iruzkinak edukitako hiperesteka(k)',
	'info_liens_titre' => 'Iruzkinaren izenburuak edukitako hiperesteka(k)',
	'info_mode_fonctionnement_defaut_forum_public' => 'Foro publikoenfuntzionamendua',
	'info_nb_messages_forum' => '@nb@ iruzkin',
	'info_option_email' => 'Guneko bisitari batek artikulu batekin erlazionatutako mezu berri bat bidaltzen duenean foroan, artikuluaren idazleak mezu honetaz abisatuakizan ahal dira e-mailez. Aukera hau erabili nahi duzu ?', # MODIF
	'info_pas_de_forum' => 'fororik ez',
	'info_question_visiteur_ajout_document_forum' => 'Foroko mezuei dokumentuen eranstea onartzen baduzu (irudi, soinu..), onartutako fitxategi-luzapenak zehaztu itzazu ((ad : gif, jpg, p,png,mp3).', # MODIF
	'info_question_visiteur_ajout_document_forum_format' => 'Beharrez, zehaztu izkizu foroetako dokumentu erantsien fitxategi-luzapen onartuak (ad : gif, jpg, png, mp3).',
	'info_selectionner_message' => 'Mezuak hautatu :',
	'interface_formulaire' => 'Inprimaki interfazea',
	'interface_onglets' => 'Fitxekilako interfazea',
	'item_activer_forum_administrateur' => 'Administrazio-taldearen foroa aktibatu.', # MODIF
	'item_config_forums_prive_global' => 'Idazleen foroa aktibatu', # MODIF
	'item_config_forums_prive_objets' => 'Foro hauek aktibatu',
	'item_desactiver_forum_administrateur' => 'Administrazio-foroa desaktibatu', # MODIF
	'item_non_config_forums_prive_global' => 'idazleen foroa desaktibatu', # MODIF
	'item_non_config_forums_prive_objets' => 'Foro hauek desaktibatu',

	// L
	'label_selectionner' => 'Hautatu :',
	'lien_reponse_article' => 'Artikuluari erantzuna',
	'lien_reponse_breve_2' => 'Atalari erantzuna',
	'lien_reponse_message' => 'Mezuari erantzuna',
	'lien_reponse_rubrique' => 'Atalari erantzuna',
	'lien_reponse_site_reference' => 'Aipatutako guneari erantzuna',
	'lien_vider_selection' => 'Selekzioa hustu',

	// M
	'messages_aucun' => 'Bat ere ez',
	'messages_meme_auteur' => 'Autore honen mezu guztiak', # MODIF
	'messages_meme_email' => 'Helbide elektroniko honen mezu guztia',
	'messages_meme_ip' => 'IP helbide honen mezu guztiak',
	'messages_off' => 'Kenduak',
	'messages_perso' => 'Pertsonala',
	'messages_privadm' => 'Administrazaile', # MODIF
	'messages_prive' => 'Pribatuak',
	'messages_privoff' => 'Ezabatuak',
	'messages_privrac' => 'Orokorrak',
	'messages_prop' => 'Proposatuak',
	'messages_publie' => 'Argitaratuak',
	'messages_spam' => 'Spam',
	'messages_tous' => 'Guztiak',

	// O
	'onglet_messages_internes' => 'Barne mezuak',
	'onglet_messages_publics' => 'Mezu publikoak',
	'onglet_messages_vide' => 'Testurik gabeko mezuak',

	// R
	'repondre_message' => 'Mezuari erantzun',

	// S
	'statut_off' => 'Ezabatua',
	'statut_original' => 'jatorrizkoa',
	'statut_prop' => 'Proposatuak',
	'statut_publie' => 'Argitaratua',
	'statut_spam' => 'Spam',

	// T
	'text_article_propose_publication_forum' => 'Ez beldurtu zure iritzia emateaz. Artikuluari foro bat lotua zaio (orri beherean).',
	'texte_en_cours_validation' => 'Artikulu, berri-labur eta iruzkin horiek argitalpenarako proposatuak dira.',
	'texte_en_cours_validation_forum' => 'Ez izan zalantzarik zure iritzia emateko beraiei erantsitako foroei esker.',
	'texte_messages_publics' => 'Mezu publikoak hemen :',
	'titre_cadre_forum_administrateur' => 'Administrarien foroa', # MODIF
	'titre_cadre_forum_interne' => 'Barneko foroa',
	'titre_config_forums_prive' => 'Eremu pribatuko foroak',
	'titre_forum' => 'Barne-foroa',
	'titre_forum_suivi' => 'Foruen kudeaketa',
	'titre_page_forum_suivi' => 'Foruenjarraipena',
	'titre_selection_action' => 'Hautua',
	'tout_voir' => 'Mezu guztiak ikusi',

	// V
	'voir_messages_objet' => 'mezuak ikusi',
];
